;; Generated package description from minimail.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "minimail" "0.4.0.20260427.90919" "Simple, non-blocking IMAP email client" '((emacs "30.1") (transient "0.12")) :commit "453a3c862b565288eacfc07c47bb22d4eefb6cf5" :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :keywords '("mail") :url "https://codeberg.org/astoff/minimail")
